@@ -20,7 +20,8 @@ class AdsConf(AppConf):
                 'xs': '720x150',
                 'sm': '800x90',
                 'md': '800x90',
-                'lg': '800x90'
+                'lg': '800x90',
+                'xl': '800x90'                
             },
             'google_adsense_slot': None,  # 'xxxxxxxxx',
             'google_adsense_format': None,  # 'auto'
@@ -31,7 +32,8 @@ class AdsConf(AppConf):
                 'xs': '720x150',
                 'sm': '800x90',
                 'md': '800x90',
-                'lg': '800x90'
+                'lg': '800x90',
+                'xl': '800x90'                
             },
             'google_adsense_slot': None,  # 'xxxxxxxxx',
             'google_adsense_format': None,  # 'auto'
@@ -42,7 +44,8 @@ class AdsConf(AppConf):
                 'xs': '720x150',
                 'sm': '800x90',
                 'md': '800x90',
-                'lg': '800x90'
+                'lg': '800x90',
+                'xl': '800x90'
             }
         }
     }
@@ -50,8 +53,17 @@ class AdsConf(AppConf):
     DEFAULT_AD_SIZE = '720x150'
 
     DEVICES = (
-        ('xs', _('Smartphones')),
-        ('sm', _('Tablets')),
-        ('md', _('Small Desktops')),
-        ('lg', _('Large Desktops'))
+        ('xs', _('Extra small devices')),
+        ('sm', _('Small devices')),
+        ('md', _('Medium devices (Tablets)')),
+        ('lg', _('Large devices (Desktops)')),
+        ('xl', _('Extra large devices (Large Desktops)')),
     )
+    
+    VIEWPORTS = {
+        'xs': 'd-block img-fluid d-sm-none',
+        'sm': 'd-none img-fluid d-sm-block d-md-none',
+        'md': 'd-none img-fluid d-md-block d-lg-none',
+        'lg': 'd-none img-fluid d-lg-block d-xl-none',
+        'xl': 'd-none img-fluid d-xl-block',
+    }
